.. _gefs-archive:

GEFS Archive
############

Archived forecasts from NOAA's
`Global Ensemble Forecast System (GEFS) <https://www.ncei.noaa.gov/products/weather-climate-models/global-ensemble-forecast>`_
are available
via `this AWS bucket <https://registry.opendata.aws/noaa-gefs/>`_.

Currently, only a limited amount of data are available from the following grib ``typeOfLevel`` filters are available:

* ``isobaricInhPa`` see available pressure levels below

* ``surface``

* ``heightAboveGround``


Available Pressure Levels
-------------------------

.. include:: levels.gefs.rst


Available Variables
-------------------

.. include:: variables.gefs.rst
